@@ -62,17 +62,24 @@ class Recipe(BaseSlapRecipe):
         ipv6_address=ipv6,
         proxy_host=ipv4,
         proxy_port=proxy_port,
-        proxy_database=os.path.join(workdir, 'proxy.db')
+        proxy_database=os.path.join(workdir, 'proxy.db'),
+	git=self.options['git'],
+	ssh_client=self.options['ssh_client'],
+	public_key=self.options['public_key'],
+	private_key=self.options['private_key']
     )
     config_file = self.createConfigurationFile('slapos.cfg',
         self.substituteTemplate(pkg_resources.resource_filename(__name__,
           'template/slapos.cfg.in'), configuration))
     self.path_list.append(config_file)
     
-    execute_arguments = dict(path = os.environ['PATH'],
-        launch_args = [self.options['slaprunner'].strip(), config_file])
+    environment = dict(
+        PATH=os.path.dirname(self.options['git']) + ':' + os.environ['PATH'],
+        GIT_SSH=self.options['ssh_client']
+    )
+    launch_args = [self.options['slaprunner'].strip(), config_file, '--debug']
     self.path_list.extend(zc.buildout.easy_install.scripts([('slaprunner',
-      'slapos.recipe.slaprunner.execute', 'execute')], self.ws, sys.executable,
-      self.wrapper_directory, arguments=execute_arguments))
+      'slapos.recipe.librecipe.execute', 'executee')], self.ws, sys.executable,
+      self.wrapper_directory, arguments=[launch_args, environment]))
     self.setConnectionDict(dict(url='http://[%s]:%s' % (ipv6, runner_port)))
     return self.path_list
